<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>BlockList</name>
    <message>
        <location filename="../BlockList.js" line="+453"/>
        <location line="+41"/>
        <location line="+39"/>
        <source>Block List</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Lista bloków</translatorcomment>
        <translation>Lista bloków</translation>
    </message>
    <message>
        <location line="-80"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Hide internal blocks</source>
        <translation>Ukrycie wewnętrznych bloków</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Enable alternating row colors</source>
        <translation>Naprzemienne kolory wierszy</translation>
    </message>
</context>
</TS>
